#Import data

haiti_data <- fread(
  paste0(haiti_data_filepath, "Analysis/haiti_data.csv"), na.strings = ""
)
rwanda_data <- fread(
  paste0(rwanda_data_filepath, "Analysis/rwanda_data.csv"), na.strings = ""
)
kenya_data <- fread(
  paste0(kenya_data_filepath, "Analysis/kenya_data.csv"), na.strings = ""
)


# Define a function to run the regressions for each country and outcome
run_regressions <- function(data) {
  reg1 <- lm_robust(any_work ~ treat_female_only, data = data, fixed_effects = as.factor(strataid),
                    clusters = as.factor(villageid))
  reg2 <- lm_robust(woman_work ~ treat_female_only, data = data, fixed_effects = as.factor(strataid),
                    clusters = as.factor(villageid))
  
  return(list(any_work = reg1, woman_work = reg2))
}

# Run regressions for each country and store the results
haiti_participation_regression <- run_regressions(haiti_data)
rwanda_participation_regression <- run_regressions(rwanda_data)
kenya_participation_regression <- run_regressions(kenya_data)

extract_results_with_details <- function(model, data, outcome_variable) {
  coef <- formatC(round(model$coefficients["treat_female_only"], 3), format = "f", digits = 3)
  se <- formatC(round(model$std.error["treat_female_only"], 3), format = "f", digits = 3)
  p_value <- formatC(round(model$p.value["treat_female_only"], 3), format = "f", digits = 3)
  
  # Calculate average for the outcome variable when treat_female_only == 0
  avg_treat_0 <- formatC(round(mean(data[data$treat_female_only == 0, ][[outcome_variable]], na.rm = TRUE), 3), format = "f", digits = 3)
  
  # Extract additional statistics
  n_obs <- model$nobs
  n_clusters <- length(unique(data$villageid))
  
  return(list(coef = coef, se = se, p_value = p_value, avg_treat_0 = avg_treat_0, 
              n_obs = n_obs, n_clusters = n_clusters))
}


# Extract formatted results for each outcome and country
haiti_any_work <- extract_results_with_details(haiti_participation_regression$any_work, haiti_data, "any_work")
rwanda_any_work <- extract_results_with_details(rwanda_participation_regression$any_work, rwanda_data, "any_work")
kenya_any_work <- extract_results_with_details(kenya_participation_regression$any_work, kenya_data, "any_work")

haiti_woman_work <- extract_results_with_details(haiti_participation_regression$woman_work, haiti_data, "woman_work")
rwanda_woman_work <- extract_results_with_details(rwanda_participation_regression$woman_work, rwanda_data, "woman_work")
kenya_woman_work <- extract_results_with_details(kenya_participation_regression$woman_work, kenya_data, "woman_work")

table_2 <- paste0("
\\documentclass{standalone}
\\usepackage[utf8]{inputenc}
\\usepackage{graphicx}
\\usepackage{booktabs}

\\begin{document}
\\begin{tabular}{lcccccc}
\\hline\\hline

& \\multicolumn{3}{c}{Man or woman participated in CFW} & \\multicolumn{3}{c}{Woman participated in CFW}\\\\
\\cmidrule(lr){2-4}\\cmidrule(lr){5-7}
 & Haiti & Kenya & Rwanda & Haiti & Kenya & Rwanda \\\\
& (1) & (2) & (3) & (4) & (5) & (6) \\\\\
\\hline
Gender Tagging & ", haiti_any_work$coef, " & ", kenya_any_work$coef, " & ", rwanda_any_work$coef, " & ", haiti_woman_work$coef, " & ", kenya_woman_work$coef, " & ", rwanda_woman_work$coef, " \\\\
 & (",haiti_any_work$se,") & (", kenya_any_work$se, ") & (", rwanda_any_work$se, ") & (", haiti_woman_work$se, ") & (", kenya_woman_work$se, ") & (", rwanda_woman_work$se, ") \\\\
 & [", haiti_any_work$p_value, "] & [", kenya_any_work$p_value, "] & [", rwanda_any_work$p_value, "] & [", haiti_woman_work$p_value, "] & [", kenya_woman_work$p_value, "] & [", rwanda_woman_work$p_value, "] \\\\
\\hline
Status Quo CFW Mean  & ", haiti_any_work$avg_treat_0, " & ", kenya_any_work$avg_treat_0, " & ", rwanda_any_work$avg_treat_0, " & ", haiti_woman_work$avg_treat_0, " & ", kenya_woman_work$avg_treat_0, " & ", rwanda_woman_work$avg_treat_0, " \\\\
\\# of observations & ", haiti_any_work$n_obs, " & ", kenya_any_work$n_obs, " & ", rwanda_any_work$n_obs, " & ", haiti_woman_work$n_obs, " & ", kenya_woman_work$n_obs, " & ", rwanda_woman_work$n_obs, " \\\\
\\# of clusters & ", haiti_any_work$n_clusters, " & ", kenya_any_work$n_clusters, " & ", rwanda_any_work$n_clusters, " & ", haiti_woman_work$n_clusters, " & ", kenya_woman_work$n_clusters, " & ", rwanda_woman_work$n_clusters, " \\\\
\\hline\\hline
\\end{tabular}
\\end{document}")

writeLines(table_2, paste0(outputs_filepath, "Table 2.tex"))

 tinytex::pdflatex(
   file     = paste0(outputs_filepath, "Table 2.tex"),
   pdf_file = paste0(outputs_filepath, "Table 2.pdf")
 )

