#Import data

haiti_data <- fread(
  paste0(haiti_data_filepath, "Analysis/haiti_data.csv"), na.strings = ""
)
rwanda_data <- fread(
  paste0(rwanda_data_filepath, "Analysis/rwanda_data.csv"), na.strings = ""
)
kenya_data <- fread(
  paste0(kenya_data_filepath, "Analysis/kenya_data.csv"), na.strings = ""
)

variables_to_check <- c("bl_number_of_children_18", "bl_num_mem", "bl_stand_fcs_score",
                        "bl_monthly_predicted_cons_winsorized_ppp", "bl_female_hoh_wage_earnings",
                        "bl_male_hoh_wage_earnings", "bl_female_work_paid_total", "bl_female_work_se_total", 
                        "bl_female_chores_total", "bl_female_location_outside", "bl_female_hoh_consumption_cse_index",
                        "bl_female_hoh_female_agency_cse_index", "bl_female_hoh_female_attitudes_tu_cse_index", 
                        "bl_female_hoh_female_attitudes_female_agency_cse_index", "bl_female_hoh_female_attitudes_consumption_cse_index",
                        "bl_locus_control_score", "bl_welfare_cse_index", "bl_c_age_01", "bl_age_diff",
                        "bl_other_women_hetero", "bl_female_hoh_employed", "bl_ipv_cse_index", "bl_female_hoh_perceptions_tu_cse_index",
                        "bl_female_hoh_perceptions_female_agency_cse_index", "bl_female_hoh_perceptions_consumption_cse_index",
                        "bl_female_hoh_perceptions_attitudes_tu_cse_index",
                        "bl_female_hoh_perceptions_attitudes_female_agency_cse_index", "bl_female_hoh_perceptions_attitudes_consumption_cse_index")

## TABLE 3 ##
#Regressions for all untreated data:
# Function to compute F-statistic, p-value, # of covariates, and # of observations
compute_regression_stats <- function(data, predictors) {
  
  untreated <- data %>% filter(treat_female_only == 0)
  
  # Keep predictors present in the dataset
  predictors <- intersect(predictors, colnames(untreated))
  if (length(predictors) == 0) return(NULL) # Skip if no predictors are found
  
  # Run the regression
  formula <- as.formula(paste("woman_work ~", paste(predictors, collapse = " + ")))
  model <- lm_robust(formula, data = untreated)
  
  # Extract F-statistic and p-value
  model_summary <- summary(model)
  f_stat_value <- model_summary$fstatistic["value"]
  numdf <- model_summary$fstatistic["numdf"]
  dendf <- model_summary$fstatistic["dendf"]
  p_value <- pf(f_stat_value, numdf, dendf, lower.tail = FALSE)
  nobs <- model$nobs
  
  # Return the results
  list(
    f_stat = f_stat_value,
    numdf = numdf,
    dendf = dendf,
    p_val = p_value,
    n_covariates = length(predictors),
    n_obs = nobs
  )
}

# Apply the function to each country's data
results <- list(
  Haiti = compute_regression_stats(haiti_data, variables_to_check),
  Rwanda = compute_regression_stats(rwanda_data, variables_to_check),
  Kenya = compute_regression_stats(kenya_data, variables_to_check)
)

# Prepare the results for the table
table_data <- data.frame(
  "Row Type" = c(
    "F-statistic",
    "",
    "\\# of covariates",
    "\\# of observations"
  ),
  Haiti = c(
    paste0("$F_{", results$Haiti$numdf, ",", results$Haiti$dendf, "} = ", sprintf("%.3f", results$Haiti$f_stat), "$"),
    sprintf("[%.3f]", results$Haiti$p_val),
    results$Haiti$n_covariates,
    results$Haiti$n_obs
  ),
  Kenya = c(
    paste0("$F_{", results$Kenya$numdf, ",", results$Kenya$dendf, "} = ", sprintf("%.3f", results$Kenya$f_stat), "$"),
    sprintf("[%.3f]", results$Kenya$p_val),
    results$Kenya$n_covariates,
    results$Kenya$n_obs
  ),
  Rwanda = c(
    paste0("$F_{", results$Rwanda$numdf, ",", results$Rwanda$dendf, "} = ", sprintf("%.3f", results$Rwanda$f_stat), "$"),
    sprintf("[%.3f]", results$Rwanda$p_val),
    results$Rwanda$n_covariates,
    results$Rwanda$n_obs
  )
)

# Generate the LaTeX table
table_3 <- kbl(
  table_data, 
  format = "latex", 
  escape = FALSE,
  booktabs = TRUE,
  digits = 3, 
  col.names = c("", "Haiti", "Kenya", "Rwanda")
)

part_1 <-  unlist(strsplit(table_3, "\n"))[6:7]
part_2 <-  unlist(strsplit(table_3, "\n"))[8:9]

table_3 <- paste0(
  "\\documentclass{standalone}
  \\usepackage[utf8]{inputenc}
  \\usepackage{graphicx}
  \\usepackage{booktabs}
  \\begin{document}
  \\begin{tabular}[t]{lccc}
  \\toprule
  & \\multicolumn{3}{c}{Woman participated in CFW} \\\\
  \\cmidrule(lr){2-4}
  & Haiti & Kenya & Rwanda \\\\
  & (1) & (2) & (3) \\\\
  \\midrule \\\\", 
  paste(part_1, collapse = "\n"),
  "\\hline",
  paste(part_2, collapse = "\n"),
  "\\bottomrule
  \\end{tabular}
  \\end{document}")
  

# Save to file
writeLines(table_3, paste0(outputs_filepath, "Table 3.tex"))

 tinytex::pdflatex(
   file     = paste0(outputs_filepath, "Table 3.tex"),
   pdf_file = paste0(outputs_filepath, "Table 3.pdf")
 )


