#Import data

haiti_data <- fread(
  paste0(haiti_data_filepath, "Analysis/haiti_data.csv"), na.strings = ""
)
rwanda_data <- fread(
  paste0(rwanda_data_filepath, "Analysis/rwanda_data.csv"), na.strings = ""
)
kenya_data <- fread(
  paste0(kenya_data_filepath, "Analysis/kenya_data.csv"), na.strings = ""
)


### RSS WITH OLS AND BOOTSTRAP ###

variables_to_check <- c("bl_number_of_children_18", "bl_num_mem", "bl_stand_fcs_score",
                        "bl_monthly_predicted_cons_winsorized_ppp", "bl_female_hoh_wage_earnings",
                        "bl_male_hoh_wage_earnings", "bl_female_work_paid_total", "bl_female_work_se_total", 
                        "bl_female_chores_total", "bl_female_location_outside", "bl_female_hoh_consumption_cse_index",
                        "bl_female_hoh_female_agency_cse_index", "bl_female_hoh_female_attitudes_tu_cse_index", 
                        "bl_female_hoh_female_attitudes_female_agency_cse_index", "bl_female_hoh_female_attitudes_consumption_cse_index",
                        "bl_locus_control_score", "bl_welfare_cse_index", "bl_c_age_01", "bl_age_diff",
                        "bl_other_women_hetero", "bl_female_hoh_employed", "bl_ipv_cse_index", "bl_female_hoh_perceptions_tu_cse_index",
                        "bl_female_hoh_perceptions_female_agency_cse_index", "bl_female_hoh_perceptions_consumption_cse_index",
                        "bl_female_hoh_perceptions_attitudes_tu_cse_index",
                        "bl_female_hoh_perceptions_attitudes_female_agency_cse_index", "bl_female_hoh_perceptions_attitudes_consumption_cse_index")


run_repeated_split_sample <- function(country_data, country_name, variables_to_check, n_iterations = 250, n_bootstrap = 100) {
  
  # Modify the data
  data <- country_data
  data$treat <- data$treat_female_only
  
  # Define the estimation variables
  estimation_variables <- data %>%
    select(any_of(variables_to_check)) %>%
    colnames()
  
  # Initialize vectors for alphas in the original sample
  alphas1_original <- numeric(n_iterations)
  alphas2_original <- numeric(n_iterations)
  alphas3_original <- numeric(n_iterations)
  sum_original <- numeric(n_iterations)
  
  # Perform the iterations within the original sample
  for (m in 1:n_iterations) {
    
    untreated <- data %>% filter(treat == 0)
    treated_group <- data %>% filter(treat == 1)
    
    villages <- unique(untreated$villageid)
    villages_group_1 <- sample(villages, length(villages) / 2)
    
    untreated <- untreated %>%
      mutate(estimation_group = ifelse(villageid %in% villages_group_1, 1, 0))
    estimation_group_data <- untreated %>% filter(estimation_group == 1)
    prediction_group <- untreated %>% filter(estimation_group == 0)
    
    formula_pred <- as.formula(paste("woman_work ~", paste(estimation_variables, collapse = " + ")))
    pred_model <- lm_robust(formula_pred, data = prediction_group, clusters = villageid)
    
    combined_group <- bind_rows(treated_group, estimation_group_data)
    combined_group$predicted_participation <- predict(pred_model, newdata = combined_group)
    
    formula_final <- as.formula("woman_work ~ treat + treat * predicted_participation + predicted_participation")
    final_model <- lm_robust(formula = formula_final, data = combined_group, clusters = villageid, fixed_effects = strataid)
    
    coefs <- coef(final_model)
    alphas1_original[m] <- coefs["treat"]
    alphas2_original[m] <- coefs["treat:predicted_participation"]
    alphas3_original[m] <- coefs["predicted_participation"]
    sum_original[m] <- coefs["treat:predicted_participation"] + coefs["predicted_participation"]
  }
  
  # Calculate the final alphas for the original sample
  final_alpha1_original <- mean(alphas1_original)
  final_alpha2_original <- mean(alphas2_original)
  final_alpha3_original <- mean(alphas3_original)
  final_sum_original <- mean(sum_original)
  
  nobs <- sum(complete.cases(rwanda_data[, ..variables_to_check]))
  nclusters <- length(unique(data$villageid))
  
  # Initialize storage for bootstrapped alphas
  boot_alphas1 <- numeric(n_bootstrap)
  boot_alphas2 <- numeric(n_bootstrap)
  boot_alphas3 <- numeric(n_bootstrap)
  boot_sum <- numeric(n_bootstrap)
  
  # Perform bootstrap
  for (b in 1:n_bootstrap) {
    
    num_villages <- data %>%
      distinct(villageid) %>%
      n_distinct()
    
    sampled_villages <- data %>%
      distinct(villageid) %>%
      sample_n(size = num_villages, replace = TRUE)
    
    duplication_counts <- sampled_villages %>%
      count(villageid, name = "duplication_count")
    
    # Duplicate individuals from villages sampled multiple times
    boot_data <- data %>%
      inner_join(duplication_counts, by = "villageid") %>%
      uncount(duplication_count, .remove = FALSE)
    
    boot_data <- boot_data %>%
      group_by(a_country_hhid) %>%
      mutate(repetition = row_number()) %>%
      ungroup() %>%
      mutate(village_new_id = paste(villageid, repetition, sep = "_"))
    
    boot_alphas1_iteration <- numeric(n_iterations)
    boot_alphas2_iteration <- numeric(n_iterations)
    boot_alphas3_iteration <- numeric(n_iterations)
    boot_sum_iteration <- numeric(n_iterations)
    
    for (m in 1:n_iterations) {
      boot_untreated <- boot_data %>% filter(treat == 0)
      treated_group <- boot_data %>% filter(treat == 1)
      
      villages <- unique(boot_untreated$village_new_id)
      villages_group_1 <- sample(villages, length(villages) / 2)
      
      boot_untreated <- boot_untreated %>%
        mutate(estimation_group = ifelse(village_new_id %in% villages_group_1, 1, 0))
      
      estimation_group_data <- boot_untreated %>% filter(estimation_group == 1)
      prediction_group <- boot_untreated %>% filter(estimation_group == 0)
      
      formula_pred <- as.formula(paste("woman_work ~", paste(estimation_variables, collapse = " + ")))
      pred_model <- lm_robust(formula_pred, data = prediction_group, clusters = villageid)
      
      combined_group <- bind_rows(treated_group, estimation_group_data)
      combined_group$predicted_participation <- predict(pred_model, newdata = combined_group)
      
      formula_final <- woman_work ~ treat + treat * predicted_participation + predicted_participation
      final_model <- lm_robust(formula_final, data = combined_group, clusters = villageid, fixed_effects = strataid)
      coefs <- coef(final_model)
      boot_alphas1_iteration[m] <- coefs["treat"]
      boot_alphas2_iteration[m] <- coefs["treat:predicted_participation"]
      boot_alphas3_iteration[m] <- coefs["predicted_participation"]
      boot_sum_iteration[m] <- coefs["treat:predicted_participation"] + coefs["predicted_participation"]
    }
    boot_alphas1[b] <- mean(boot_alphas1_iteration)
    boot_alphas2[b] <- mean(boot_alphas2_iteration)
    boot_alphas3[b] <- mean(boot_alphas3_iteration)
    boot_sum[b] <- mean(boot_sum_iteration)
    
    print(paste("Completed bootstrap iteration", b, "of", n_bootstrap))
    
  }
  
  # Calculate standard errors from bootstrapped estimates
  boot_se1 <- sd(boot_alphas1)
  boot_se2 <- sd(boot_alphas2)
  boot_se3 <- sd(boot_alphas3)
  boot_se_sum <- sd(boot_sum)
  
  # Calculate RI p-values
  ri_pvalue1 <- mean(abs(boot_alphas1) >= abs(final_alpha1_original))
  ri_pvalue2 <- mean(abs(boot_alphas2) >= abs(final_alpha2_original))
  ri_pvalue3 <- mean(abs(boot_alphas3) >= abs(final_alpha3_original))
  ri_pvalue_sum <- mean(abs(boot_sum) >= abs(final_sum_original))
  
  # Calculate standard p-values
  pvalue1 <- 2 * (1 - pnorm(abs(final_alpha1_original / boot_se1)))
  pvalue2 <- 2 * (1 - pnorm(abs(final_alpha2_original / boot_se2)))
  pvalue3 <- 2 * (1 - pnorm(abs(final_alpha3_original / boot_se3)))
  pvalue_sum <- 2 * (1 - pnorm(abs(final_sum_original / boot_se_sum)))
  
  # Return the results
  return(list(
    alphas_original = c(alpha1 = final_alpha1_original, alpha2 = final_alpha2_original, alpha3 = final_alpha3_original, sum = final_sum_original),
    boot_se = c(se_alpha1 = boot_se1, se_alpha2 = boot_se2, se_alpha3 = boot_se3, se_sum = boot_se_sum),
    ri_pvalues = c(ri_pvalue1 = ri_pvalue1, ri_pvalue2 = ri_pvalue2, ri_pvalue3 = ri_pvalue3, ri_pvalue_sum = ri_pvalue_sum),
    pvalues = c(pvalue1 = pvalue1, pvalue2 = pvalue2, pvalue3 = pvalue3, pvalue_sum = pvalue_sum),
    alphas1 = boot_alphas1, alphas2 = boot_alphas2, alphas3 = boot_alphas3, sum = boot_sum,
    nobs = nobs, nclusters = nclusters
  ))
}
set.seed(986545)
rwanda_rss_ols_bootrstrap <- run_repeated_split_sample(rwanda_data, Rwanda, variables_to_check, n_iterations = 250, n_bootstrap = 100)
rwanda_rss_ols_bootrstrap

# Round numbers to three decimal places
alphas <- round(rwanda_rss_ols_bootrstrap$alphas_original[c("alpha3", "alpha1", "alpha2", "sum")], 3)
se <- round(rwanda_rss_ols_bootrstrap$boot_se[c("se_alpha3", "se_alpha1", "se_alpha2", "se_sum")], 3)
pvalues <- round(rwanda_rss_ols_bootrstrap$pvalues[c("pvalue3", "pvalue1", "pvalue2", "pvalue_sum")], 3)
nobs <- rwanda_rss_ols_bootrstrap$nobs
nclustres <- rwanda_rss_ols_bootrstrap$nclusters

# Create data frame
results <- data.frame(
  Name = c(
    "$\\delta_{1c}$: Predicted Woman",
    "$\\delta_{2c}$: Gender Tagging",
    "$\\delta_{3c}$: Gender Tagging $\\times$ Predicted Woman",
    "$\\delta_{1c}$ + $\\delta_{3c}$"
  ),
  Alpha = sprintf("%.3f", alphas),
  SE = sprintf("(%.3f)", se),
  P_value = sprintf("[%.3f]", pvalues)
)

# Generate LaTeX table rows
latex_table <- apply(results, 1, function(row) {
  if (row['Name'] %in% c(
    "$\\delta_{1c}$: Predicted Woman",
    "$\\delta_{3c}$: Gender Tagging $\\times$ Predicted Woman"
  )) {
    # Include indented second line for first and third delta
    paste0(row['Name'], " & ", row['Alpha'], " \\\\ \n",
           "\\hspace{1em} Participated in Status Quo CFW & ", row['SE'], " \\\\ \n",
           " & ", row['P_value'], " \\\\")
  } else {
    # Regular format for others
    paste0(row['Name'], " & ", row['Alpha'], " \\\\ \n",
           " & ", row['SE'], " \\\\ \n",
           " & ", row['P_value'], " \\\\")
  }
})

# Add LaTeX table structure with # of observations and # of clusters
table_4 <- paste0(
  "\\documentclass{standalone}",
  "\\usepackage[utf8]{inputenc}",
  "\\usepackage{graphicx}",
  "\\usepackage{booktabs}",
  "\\begin{document}",
  "\\begin{tabular}{lc}\n",
  "\\hline\n",
  "\\hline\n",
  " & Woman Participated in CFW \\\\\n",
  " & \\cline{1-1}",
  " & Rwanda \\\\\n",
  " & (1) \\\\\n",
  "\\hline\n",
  paste(latex_table[1:3], collapse = "\n"),
  "\\hline\n",  # Add horizontal line before the sum row
  latex_table[4],  # Include the sum row
  "\\hline\n",
  "\\# of observations & ", nobs, " \\\\ \n",
  "\\# of clusters & ", nclustres, " \\\\ \n",
  "\\hline\n",
  "\\hline\n",
  "\\end{tabular}",
  "\\end{document}"
)

# Print LaTeX table
cat(table_4)

writeLines(table_4, paste0(outputs_filepath, "Table 4.tex"))

 tinytex::pdflatex(
   file     = paste0(outputs_filepath, "Table 4.tex"),
   pdf_file = paste0(outputs_filepath, "Table 4.pdf")
 )